@@ -335,7 +335,11 @@ def read_binary_file(input_path, output_file=None):
     ipath = Path(input_path)
     if not ipath.is_file():
         raise Exception("File %s not found. Abort." % (str(ipath.absolute())))
-    if ipath.suffix not in supported_file_extensions and not ipath.suffix.startswith('.ssp') and not ipath.suffix.startswith('.sst'):
+
+    if (ipath.suffix not in supported_file_extensions)\
+    and (not ipath.suffix.startswith('.ssp')) and\
+    (not ipath.suffix.startswith('.sst')) and\
+    (not ipath.suffix.startswith('.jsp')):
         raise Exception("Extention of file %s not in allowed list. Abort." % (str(ipath.absolute())))
 
     if isinstance(output_file,str):
@@ -862,7 +866,7 @@ def add_entry(data, key, moddata, dtype, units, description, scale, xbase, tag=N
     return odata
 
 
-def modify_entry(data, key, moddata, tag=None):
+def modify_entry(data, key, moddata, dtype=None, units=None, description=None, scale=None, tag=None):
     """
     Use this function to modify the Python data structure
     generated by this tool, in order to prepare it for
@@ -886,16 +890,43 @@ def modify_entry(data, key, moddata, tag=None):
     if isinstance(data, (dict, collections.OrderedDict)) and ikey in data:
         if data[ikey].size == idata.size:
             idata = np.reshape(idata, data[ikey].shape)
-        if data[ikey].shape == idata.shape:
-            uname = getuser()
+        writeData = False
+        dataShape = None
+        if "XBASE" in data["INFO"][ikey]:
+            if data["INFO"][ikey]["XBASE"] == "XVEC1":
+                dataShape = (data["TVEC1"].shape[0], data["XVEC1"].shape[1])
+            elif data["INFO"][ikey]["XBASE"] == "TVEC1":
+                dataShape = (1, data["TVEC1"].shape[0])
+            else:
+                print(f"   Unrecognised XBASE for {ikey}: {data['INFO'][ikey]['XBASE']}.")
+            if idata.shape == dataShape:
+                writeData = True
+            elif isinstance(dataShape, (list, tuple)):
+                print("   Input data is not the same shape as existing data structure: ", dataShape)
+        else:
+            if ikey in ["XVEC1", "TVEC1"]:
+                writeData = True
+            else:
+                print(f"   XBASE is missing for {ikey} in existing data structure.")
+        if writeData:
             odata = copy.deepcopy(data)
             odata[ikey] = idata.copy()
-            odata["INFO"][ikey]["UID"] = uname    # User ID (auto-detected)
-            odata["INFO"][ikey]["DDA"] = itag     # DDA name in PPF system (replaced with metadata)
-            odata["INFO"][ikey]["DTYPE"] = ''     # Data field name in PPF system (replaced with empty string)
-            odata["INFO"][ikey]["SEQ"] = '0'      # Sequence number in PPF system (replaced with zero string)
-        else:
-            print("   Input data is not the same shape as existing data structure: ", data[ikey].shape)
+            if ikey not in ["XVEC1", "TVEC1"]:
+                uname = getuser()
+                odata["INFO"][ikey]["UID"] = uname    # User ID (auto-detected)
+                odata["INFO"][ikey]["DDA"] = itag     # DDA name in PPF system (replaced with metadata)
+                odata["INFO"][ikey]["DTYPE"] = ''     # Data field name in PPF system (replaced with empty string)
+                odata["INFO"][ikey]["SEQ"] = '0'      # Sequence number in PPF system (replaced with zero string)
+            if isinstance(units, str):
+                odata["INFO"][ikey]["UNITS"] = units            # Units string
+            if isinstance(description, str):
+                odata["INFO"][ikey]["DESC"] = description       # Description string
+            if isinstance(scale, str):
+                odata["INFO"][ikey]["SCSTR"] = scale            # String representation of scaling for writing into ex-file
+                odata["INFO"][ikey]["SCALE"] = float(scale)     # Numeric value for actual scaling operation
+            if isinstance(dtype, str):
+                odata["INFO"][ikey]["FORM"] = dtype             # Data type for conversion to binary representation
+            odata["INFO"][ikey]["LABEL"] = ikey                 # Name of data field, printed verbatim into ex-file
     elif isinstance(data, (dict, collections.OrderedDict)):
         print("   Base data to be modified does not contain the entry %s. Modification aborted.")
     else:
