@@ -645,6 +645,7 @@ class RunConfig:
         :type rundir: Path
         """
         jset = deepcopy(self._template.jset)
+        jset.collapse_all_arrays()
 
         jset_path = point_dir.joinpath('jetto.jset')
 
@@ -693,6 +694,7 @@ class RunConfig:
                 else:
                     extras[field] = jetto_tools.jset.ExtraNamelistItem(value, 1, active=active)
 
+        jset.expand_all_arrays()
         with open(jset_path, 'w') as f:
             f.write(str(jset))
 
