@@ -164,6 +164,9 @@ class JobManager:
         :raise: JobManagerError if any aspect of submitting the job fails (including Docker failures)
         """
         runpath = Path( os.path.join(JobManager._get_run_root(), rundir))
+
+        config.export(runpath, rundir)
+
         try:
             client = docker.from_env()
             container = client.containers.run(image, 
@@ -456,8 +459,8 @@ class JobManager:
 
         return [{
             'cmd': cmd,
-            'image': f'CCFE/JINTRAC/{config.userid}:{config.binary}.tgz',
-            'runtime': 'udocker'
+            'image': f'CCFE/JINTRAC/{config.userid}:{config.binary}.sif',
+            'runtime': 'singularity'
         }]
 
     @classmethod
