@@ -59,7 +59,7 @@ def read_qualikiz_gamhistory_data(rundir, gamhistory=1):
         output["k"] = k.copy()
 
     x = np.genfromtxt(str(rpath / 'x.qlk'))
-    rzero = np.genfromtxt(str(rpath / 'R0.qlk'))
+    rzero = np.genfromtxt(str(rpath / 'R0.qlk')) if (rpath / 'R0.qlk').is_file() else np.array([0.0])
     if gamhist <= 2:
         output["x"] = x.flatten()
         output["rzero"] = rzero.reshape(-1, 1)
