@@ -64,6 +64,8 @@ class Template:
         if jset.impurities and jset.sanco and sanco_namelist is None:
             raise TemplateError('SANCO configured as impurities source but SANCO namelist file not provided')
 
+        jset.collapse_all_arrays()
+
         for name, param in lookup.items():
             if Template.is_regular_param(param):
                 Template.validate_regular_param(name, param, jset, namelist, sanco_namelist)
@@ -78,6 +80,14 @@ class Template:
         self._sanco_namelist = sanco_namelist
         self._catalogue_id = catalogue_id
 
+    def collapse_jset(self):
+        """Collapse all arrays inside JSET representation"""
+        self._jset.collapse_all_arrays()
+
+    def expand_jset(self):
+        """Expand all arrays inside JSET representation"""
+        self._jset.expand_all_arrays()
+
     @classmethod
     def transform_extra_files(cls, extra_files: List[str]) -> Dict[str, str]:
         """Transform the extra file list into a dictionary
@@ -172,10 +182,7 @@ class Template:
         :raise: TemplateError if any of the checks fail
         """
         jset_ids = Template.extract_jset_ids(param)
-        dimension = param['dimension']
 
-        if dimension == 'vector':
-            raise TemplateError(f'Vector parameter {name} not supported outside of extra namelists')
         for jset_id in jset_ids:
             if jset_id not in jset:
                 raise TemplateError(f'jset_id {jset_id} not found in template JSET')
