@@ -299,9 +299,9 @@ def generate_exfile_structure(rootgrp, database, shot, tbeg=None, tend=None, met
         exdata = binary.create_exfile_structure(database, shot)
 
         xtag = 'XVEC1'
-        exdata = binary.add_entry(exdata, xtag, xvec, dtype='float', units=exfile_units[xtag], description=exfile_descriptions[xtag], scale=exfile_scales[xtag], xbase=None, tag=tag)
+        exdata = binary.modify_entry(exdata, xtag, xvec, dtype='float', units=exfile_units[xtag], description=exfile_descriptions[xtag], scale=exfile_scales[xtag])
         ttag = 'TVEC1'
-        exdata = binary.add_entry(exdata, ttag, time, dtype='float', units=exfile_units[ttag], description=exfile_descriptions[ttag], scale=exfile_scales[ttag], xbase=None, tag=tag)
+        exdata = binary.modify_entry(exdata, ttag, time, dtype='float', units=exfile_units[ttag], description=exfile_descriptions[ttag], scale=exfile_scales[ttag])
 
         # Adds radial coordinate system vectors to EX-file, only RHO is strictly needed by JETTO?
         psin = None
@@ -465,7 +465,7 @@ def generate_extfile_structure(rootgrp, database, shot, tbeg=None, tend=None, me
         extdata = binary.create_exfile_structure(database, shot, extfile=True)
 
         ttag = 'TVEC1'
-        extdata = binary.add_entry(extdata, ttag, time, dtype='float', units=extfile_units[ttag], description=extfile_descriptions[ttag], scale=extfile_scales[ttag], xbase=None, tag=tag)
+        extdata = binary.modify_entry(extdata, ttag, time, dtype='float', units=extfile_units[ttag], description=extfile_descriptions[ttag], scale=extfile_scales[ttag])
 
         # Add signals
         for ii in range(0,len(transp_ext_signals)):
