@@ -757,8 +757,8 @@ class TestSubmitSingleRunToProminence:
 
         assert job_['tasks'][0]['cmd'] == cmd
 
-    @pytest.mark.parametrize('userid, binary, image', [('sim', 'v060619', 'CCFE/JINTRAC/sim:v060619.tgz'),
-                                                       ('foo', 'bar', 'CCFE/JINTRAC/foo:bar.tgz')])
+    @pytest.mark.parametrize('userid, binary, image', [('sim', 'v060619', 'CCFE/JINTRAC/sim:v060619.sif'),
+                                                       ('foo', 'bar', 'CCFE/JINTRAC/foo:bar.sif')])
     def test_job_task_image_has_expected_values(self, mock_prominence, manager, mock_config, jintrac_env,
                                                 run_root, rundir, mock_prominence_client, userid, binary, image):
         mock_config.userid = userid
@@ -769,12 +769,12 @@ class TestSubmitSingleRunToProminence:
 
         assert job_['tasks'][0]['image'] == image
 
-    def test_job_task_runtime_is_udocker(self, mock_prominence, manager, mock_config, jintrac_env,
+    def test_job_task_runtime_is_singularity(self, mock_prominence, manager, mock_config, jintrac_env,
                                          run_root, rundir, mock_prominence_client):
         manager.submit_job_to_prominence(mock_config, rundir)
         job_ = mock_prominence_client.create_job.call_args[0][0]
 
-        assert job_['tasks'][0]['runtime'] == 'udocker'
+        assert job_['tasks'][0]['runtime'] == 'singularity'
 
     @pytest.mark.parametrize('cpus', [1, 2], ids=['Serial', 'Parallel'])
     def test_job_resources_cpus_has_expected_value(self, mock_prominence, manager, mock_config, jintrac_env,
@@ -1095,8 +1095,8 @@ class TestSubmitScanToProminence:
 
         assert task['cmd'] == cmd
 
-    @pytest.mark.parametrize('userid, binary, image', [('sim', 'v060619', 'CCFE/JINTRAC/sim:v060619.tgz'),
-                                                       ('foo', 'bar', 'CCFE/JINTRAC/foo:bar.tgz')])
+    @pytest.mark.parametrize('userid, binary, image', [('sim', 'v060619', 'CCFE/JINTRAC/sim:v060619.sif'),
+                                                       ('foo', 'bar', 'CCFE/JINTRAC/foo:bar.sif')])
     def test_workflow_task_image_has_expected_values(self, mock_prominence, manager, mock_scan_config, jintrac_env,
                                                      run_root, rundir, mock_prominence_client, userid, binary, image):
         mock_scan_config.userid = userid
@@ -1107,12 +1107,12 @@ class TestSubmitScanToProminence:
 
         assert task['image'] == image
 
-    def test_workflow_task_runtime_is_udocker(self, mock_prominence, manager, mock_scan_config, jintrac_env,
+    def test_workflow_task_runtime_is_singularity(self, mock_prominence, manager, mock_scan_config, jintrac_env,
                                               run_root, rundir, mock_prominence_client):
         manager.submit_job_to_prominence(mock_scan_config, rundir)
         task = mock_prominence_client.create_workflow.call_args[0][0]['jobs'][0]['tasks'][0]
 
-        assert task['runtime'] == 'udocker'
+        assert task['runtime'] == 'singularity'
 
     @pytest.mark.parametrize('cpus', [1, 2], ids=['Serial', 'Parallel'])
     def test_workflow_resources_cpus_has_expected_value(self, mock_prominence, manager, mock_scan_config, jintrac_env,
