@@ -132,12 +132,6 @@ class TestJettoRegularParamValidation:
         with pytest.raises(template.TemplateError):
             _ = template.Template(jset, jetto_namelist, lookup)
 
-    def test_fails_if_parameter_is_vector(self, jset, jetto_namelist, lookup):
-        lookup['param']['dimension'] = 'vector'
-
-        with pytest.raises(template.TemplateError):
-            _ = template.Template(jset, jetto_namelist, lookup)
-
     def test_passes_if_integer_param_can_be_converted(self, jset, jetto_namelist, lookup):
         jset.__getitem__.return_value = 1
         lookup['param']['type'] = 'real'
@@ -271,12 +265,6 @@ class TestSancoRegularParamValidation:
         with pytest.raises(template.TemplateError):
             _ = template.Template(jset, jetto_namelist, lookup, sanco_namelist=sanco_namelist)
 
-    def test_fails_if_parameter_is_vector(self, jset, jetto_namelist, lookup, sanco_namelist):
-        lookup['param']['dimension'] = 'vector'
-
-        with pytest.raises(template.TemplateError):
-            _ = template.Template(jset, jetto_namelist, lookup, sanco_namelist=sanco_namelist)
-
 
 class TestSancoExtraNamelistParamValidation:
     """Test that Sanco extra namelist parameters (i.e. those found in the JSET Sanco extra namelists) are validated as
